@@ -90,7 +90,8 @@ NMEA_TALKERS = {
     "GN": "Global Navigation Satellite System (GNSS)",
     "GP": "Global Positioning System (GPS)",
     "GQ": "QZSS",
-    "PU": "Proprietary UBX",
+    # "PG": "Proprietary GARMIN",
+    # "PU": "Proprietary U-BLOX",
     # ***************************************************************
     # Heading Sensors:
     # ***************************************************************
@@ -131,7 +132,23 @@ NMEA_MSGIDS = {
     "VTG": "Course over ground and Groundspeed",
     "ZDA": "Time and Date",
     # ***************************************************************
-    # NMEA Proprietary message types
+    # GARMIN Proprietary message types
+    # ***************************************************************
+    "PGRMB": "DGPS Beacon Information",
+    "PGRMC": "Set Sensor Configuration information",
+    "PGRMC1": "Set Additional Sensor Configuration Information",
+    "PGRME": "Estimated Error Information",
+    "PGRMF": "GPS Fix Data sentence",
+    "PGRMH": "Aviation Height and VNAV data",
+    "PGRMI": "Set Sensor Initialisation Information",
+    "PGRMM": "MapDatum",
+    "PGRMO": "Set Output Sentence Enable",
+    "PGRMT": "Sensor Status Information",
+    "PGRMV": "3D Velocity Information",
+    "PGRMW": "Set Additional Waypoint Information",
+    "PGRMZ": "Altitude",
+    # ***************************************************************
+    # U-BLOX Proprietary message types
     # ***************************************************************
     "PUBX00": "PUBX-POSITION Lat/Long Position Data",
     "PUBX03": "PUBX-SVSTATUS Satellite Status",
